@@ -76,10 +76,10 @@ fuselage.patchcompose(leftqueue=[wing_left], rightqueue=[wing_right], xdisc=60,
 #sld.plotnormals(xlim=[-0.1, 0.3], ylim=[0.5, 0.7], zlim=[-0.2, 0.2], factor=0.1)
 #sld.genwakepanels(wakecombs=wingquad_left.wakecombs+wingquad_right.wakecombs, wakeinds=[[0, 0]], a=a)
 acft.edit_parameters({'a':a, 'Uinf':Uinf})
-acft.addwake()
+acft.addwake(offset=10.0, wakedisc=30, strategy=lambda x: x)
 sld.plotgeometry(xlim=[-0.5, 1.5], ylim=[-1.0, 1.0], zlim=[-1.0, 1.0])
 acft.bodies_eqflatplate_apply(rho=rho, mu=mu)
-acft.eulersolve()
+acft.eulersolve(wakeiter=5)
 acft.forces_report()
 acft.stabreport()
 acft.balance()
@@ -99,7 +99,7 @@ plt.plot(CLs_visc, CDs_visc, label='viscous')
 plt.plot(CLs, CDs, label='inviscid')
 plt.legend()
 plt.show()'''
-#sld.plotgeometry(xlim=[-0.5, 1.5], ylim=[-1.0, 1.0], zlim=[-1.0, 1.0])
+acft.plotgeometry(velfield=False)
 #sld.plotgeometry(xlim=[-0.1, 0.3], ylim=[0.5, 0.7], zlim=[-0.2, 0.2])
 print('npanels: ', sld.npanels)
 plot_Cps(sld, elems=[wing_left, wing_right])
